@@ -17,14 +17,18 @@
 import json
 import sqlite3
 
+from py_singleton import singleton
+
 from digital_hydrant import logging
 from digital_hydrant.config import db_path
 
 
+@singleton
 class CollectorQueue:
     def __init__(self):
         self.logger = logging.getLogger(__name__)
         self.__table__ = "collectors"
+        self.logger.debug("CollectorQueue initialized")
 
         try:
             self.conn = sqlite3.connect(db_path, timeout=10)
