@@ -20,9 +20,11 @@ from multiprocessing import Process
 import time
 import os
 import schedule
+from configparser import ConfigParser
+
 
-from digital_hydrant.scheduler import Scheduler
 from digital_hydrant.process_manager import ProcessManager
+from digital_hydrant.config import update_config, ini_path
 
 from . import stub_collectors
 
@@ -32,6 +34,12 @@ class TestProcessManager(unittest.TestCase):
     def setUp(self):
         self.manager = ProcessManager()
         self.manager.logger = Mock()
+        self.original = ConfigParser()
+        self.original.read(ini_path)
+
+    def tearDown(self):
+        with open(ini_path, "w") as configfile:
+            self.original.write(configfile)
 
     def test_add_process(self, mock):
         m = Mock()
@@ -127,3 +135,18 @@ class TestProcessManager(unittest.TestCase):
         self.assertEqual("run_job_once", self.manager.jobs["tester"].job_func.__name__)
         self.assertEqual("seconds", self.manager.jobs["tester"].unit)
         self.assertEqual(1, self.manager.jobs["tester"].interval)
+
+    def test_check_for_new_jobs(self, mock):
+        self.manager.collectors.append("newest_section")
+        self.manager.check_for_new_jobs()
+        start = len(self.manager.process_details)
+
+        update_config({"newest_section": {"something_else": True}})
+
+        self.manager.check_for_new_jobs()
+        self.assertEqual(start, len(self.manager.process_details))
+
+        update_config({"newest_section": {"enabled": True}})
+
+        self.manager.check_for_new_jobs()
+        self.assertEqual(start + 1, len(self.manager.process_details))
